@@ -17,6 +17,7 @@
 from .graphql_queries import (
     ARTIFACTS,
     ACTIVITY_TRIGGERED,
+    ACTIVITY_CANCELED,
     CONFIDENCE_LEVEL,
     TEST_SUITE_STARTED,
     TEST_SUITE_FINISHED,
@@ -29,7 +30,7 @@ from .graphql_queries import (
 def request(etos, query):
     """Request graphql in a generator.
 
-    :param etos: ETOS client query etos.
+    :param etos: Etos Library instance for communicating with ETOS.
     :type etos: :obj:`etos_lib.etos.ETOS`
     :param query: Query to send to graphql.
     :type query: str
@@ -43,7 +44,7 @@ def request(etos, query):
 def request_suite(etos, suite_id):
     """Request a tercc from graphql.
 
-    :param etos: ETOS client query etos.
+    :param etos: Etos Library instance for communicating with ETOS.
     :type etos: :obj:`etos_lib.etos.ETOS`
     :param suite_id: ID of execution recipe.
     :type suite_id: str
@@ -66,7 +67,7 @@ def request_suite(etos, suite_id):
 def request_activity(etos, suite_id):
     """Request an activity event from graphql.
 
-    :param etos: ETOS client query etos.
+    :param etos: Etos Library instance for communicating with ETOS.
     :type etos: :obj:`etos_lib.etos.ETOS`
     :param suite_id: ID of execution recipe triggering this activity.
     :type suite_id: str
@@ -85,10 +86,32 @@ def request_activity(etos, suite_id):
     return None
 
 
+def request_activity_canceled(etos, activity_id):
+    """Request an activity event from graphql.
+
+    :param etos: Etos Library instance for communicating with ETOS.
+    :type etos: :obj:`etos_lib.etos.ETOS`
+    :param activity_id: ID of the activity beeing canceled.
+    :type activity_id: str
+    :return: Response from graphql or None
+    :rtype: dict or None
+    """
+    for response in request(etos, ACTIVITY_CANCELED % activity_id):
+        if response:
+            try:
+                _, activity_canceled = next(
+                    etos.graphql.search_for_nodes(response, "activityCanceled")
+                )
+            except StopIteration:
+                return None
+            return activity_canceled
+    return None
+
+
 def request_test_suite_started(etos, activity_id):
     """Request test suite started from graphql.
 
-    :param etos: ETOS client query etos.
+    :param etos: Etos Library instance for communicating with ETOS.
     :type etos: :obj:`etos_lib.etos.ETOS`
     :param activity_id: ID of activity in which the test suites started
     :type activity_id: str
@@ -108,7 +131,7 @@ def request_test_suite_started(etos, activity_id):
 def request_test_suite_finished(etos, test_suite_ids):
     """Request test suite finished from graphql.
 
-    :param etos: ETOS client query etos.
+    :param etos: Etos Library instance for communicating with ETOS.
     :type etos: :obj:`etos_lib.etos.ETOS`
     :param test_suite_ids: list of test suite started IDs of which finished to search for.
     :type test_suite_ids: list
@@ -137,7 +160,7 @@ def request_test_suite_finished(etos, test_suite_ids):
 def request_confidence_level(etos, test_suite_ids):
     """Request confidence levels from graphql.
 
-    :param etos: ETOS client query etos.
+    :param etos: Etos Library instance for communicating with ETOS.
     :type etos: :obj:`etos_lib.etos.ETOS`
     :param test_suite_ids: list of test suite started IDs of which confidences to search for.
     :type test_suite_ids: list
@@ -165,7 +188,7 @@ def request_confidence_level(etos, test_suite_ids):
 def request_announcements(etos, ids):
     """Request announcements from graphql.
 
-    :param etos: ETOS client query etos.
+    :param etos: Etos Library instance for communicating with ETOS.
     :type etos: :obj:`etos_lib.etos.ETOS`
     :param ids: list of IDs of which announcements to search for.
     :type ids: list
@@ -188,7 +211,7 @@ def request_announcements(etos, ids):
 def request_environment(etos, ids):
     """Request environments from graphql.
 
-    :param etos: ETOS client query etos.
+    :param etos: Etos Library instance for communicating with ETOS.
     :type etos: :obj:`etos_lib.etos.ETOS`
     :param ids: list of IDs of which environments to search for.
     :type ids: list
@@ -211,7 +234,7 @@ def request_environment(etos, ids):
 def request_artifacts(etos, context):
     """Request artifacts from graphql.
 
-    :param etos: ETOS client query etos.
+    :param etos: Etos Library instance for communicating with ETOS.
     :type etos: :obj:`etos_lib.etos.ETOS`
     :param context: ID of the activity used in CONTEXT.
     :type context: str
